Module ops

Module ops 

Functions

clone_or_fetch
Clone url into dest, or fetch all refs if the repo already exists.
create_worktree
Create a detached worktree at worktree_path pointing at ref_name.
destroy_worktree
Remove a worktree previously created with create_worktree.
get_sha
Resolve ref_name to its full SHA in repo.
list_commits
Return up to limit commits reachable from ref_name.
list_refs
Return all branches, tags, and recent commits for repo.
normalize_git_url
Convert a repository browse URL into a clonable git URL.