list_refs

Function list_refs 

pub fn list_refs(repo: &Path) -> Result<RepoRefs>
Return all branches, tags, and recent commits for repo.

Errors

Returns an error if any underlying git command fails.