pub fn parse_bitbucket_push(body: &[u8]) -> Result<WebhookEvent>Expand description
Parse a Bitbucket Server / Cloud push webhook payload.
Errors
Returns an error if the body is not valid JSON or required fields are missing.
pub fn parse_bitbucket_push(body: &[u8]) -> Result<WebhookEvent>Parse a Bitbucket Server / Cloud push webhook payload.
Returns an error if the body is not valid JSON or required fields are missing.