pub fn parse_github_push(body: &[u8]) -> Result<WebhookEvent>Expand description
Parse a GitHub push webhook payload.
Errors
Returns an error if the body is not valid JSON or required fields are missing.
pub fn parse_github_push(body: &[u8]) -> Result<WebhookEvent>Parse a GitHub push webhook payload.
Returns an error if the body is not valid JSON or required fields are missing.