pub fn clone_or_fetch(url: &str, dest: &Path) -> Result<()>Expand description
Clone url into dest, or fetch all refs if the repo already exists.
Browse URLs (GitHub, GitLab, Bitbucket web pages) are automatically converted to their corresponding git clone URLs before cloning.
Errors
Returns an error if the URL is rejected, the clone directory cannot be created,
or the underlying git clone / git fetch command fails.